
/* Generated data (by glib-mkenums) */

#ifndef __GSK_ENUM_TYPES_H__
#define __GSK_ENUM_TYPES_H__

#include <gdk/gdk.h>

G_BEGIN_DECLS

/* enumerations from "gskenums.h" */
GDK_AVAILABLE_IN_ALL GType gsk_render_node_type_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_RENDER_NODE_TYPE (gsk_render_node_type_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_scaling_filter_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_SCALING_FILTER (gsk_scaling_filter_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_blend_mode_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_BLEND_MODE (gsk_blend_mode_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_corner_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_CORNER (gsk_corner_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_serialization_error_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_SERIALIZATION_ERROR (gsk_serialization_error_get_type ())
G_END_DECLS

#endif /* __GSK_ENUM_TYPES_H__ */

/* Generated data ends here */

